##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/system/operation/systemNodesCount)Retrieve the count of nodes
**Access policy** : authenticated
##### Authorizations:
_ApiKeyAuth_ _jwt_
### Responses
**200**
Success
**500**
Server error
get/system/nodes
https://api-docs.portainer.io/api/system/nodes
###  Response samples
  * 200


Content type
application/json
Copy
`{
  *  "nodes": 0

 }`
